==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/GetBuildServiceResourceUploadUrlPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.GetBuildServiceResourceUploadUrlPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property buildServiceName The name of the build service resource.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serviceName The name of the Service resource.
 */
public data class GetBuildServiceResourceUploadUrlPlainArgs(
    public val buildServiceName: String,
    public val resourceGroupName: String,
    public val serviceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.GetBuildServiceResourceUploadUrlPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.appplatform.inputs.GetBuildServiceResourceUploadUrlPlainArgs =
        com.pulumi.azurenative.appplatform.inputs.GetBuildServiceResourceUploadUrlPlainArgs.builder()
            .buildServiceName(buildServiceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetBuildServiceResourceUploadUrlPlainArgs].
 */
@PulumiTagMarker
public class GetBuildServiceResourceUploadUrlPlainArgsBuilder internal constructor() {
    private var buildServiceName: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    /**
     * @param value The name of the build service resource.
     */
    @JvmName("ksbttvihwclxophe")
    public suspend fun buildServiceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.buildServiceName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("keobckpfbcmofcjb")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Service resource.
     */
    @JvmName("phmysbkxoajlogsq")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): GetBuildServiceResourceUploadUrlPlainArgs =
        GetBuildServiceResourceUploadUrlPlainArgs(
            buildServiceName = buildServiceName ?: throw PulumiNullFieldException("buildServiceName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/GetBuildServiceResourceUploadUrlPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.GetBuildServiceResourceUploadUrlPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property buildServiceName The name of the build service resource.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serviceName The name of the Service resource.
 */
public data class GetBuildServiceResourceUploadUrlPlainArgs(
    public val buildServiceName: String,
    public val resourceGroupName: String,
    public val serviceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.GetBuildServiceResourceUploadUrlPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.appplatform.inputs.GetBuildServiceResourceUploadUrlPlainArgs =
        com.pulumi.azurenative.appplatform.inputs.GetBuildServiceResourceUploadUrlPlainArgs.builder()
            .buildServiceName(buildServiceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetBuildServiceResourceUploadUrlPlainArgs].
 */
@PulumiTagMarker
public class GetBuildServiceResourceUploadUrlPlainArgsBuilder internal constructor() {
    private var buildServiceName: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    /**
     * @param value The name of the build service resource.
     */
    @JvmName("sbsavkqhtmcrfius")
    public suspend fun buildServiceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.buildServiceName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("gsuqhsbynwexbrun")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Service resource.
     */
    @JvmName("hgihsykosuvyuffo")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): GetBuildServiceResourceUploadUrlPlainArgs =
        GetBuildServiceResourceUploadUrlPlainArgs(
            buildServiceName = buildServiceName ?: throw PulumiNullFieldException("buildServiceName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
        )
}
